@@ -24,6 +24,8 @@
 #include <QString>
 #include <QStringList>
 
+#include "utility2.h"
+
 class QAction ;
 class QWidget ;
 class QTableWidgetItem ;
@@ -37,31 +39,6 @@ class favorites : public QDialog
 {
 	Q_OBJECT
 public:
-	template< typename E,typename F >
-	static void _stringListToStrings( const F& s,size_t n,size_t k,E& e )
-	{
-		if( n < k ){
-
-			e = s.at( n ) ;
-		}
-	}
-
-	template< typename E,typename F,typename ... T >
-	static void _stringListToStrings( const E& s,size_t n,size_t k,F& e,T& ... t )
-	{
-		if( n < k ){
-
-			e = s.at( n ) ;
-			_stringListToStrings( s,n + 1,k,t ... ) ;
-		}
-	}
-
-	template< typename E,typename ... F >
-	static void stringListToStrings( const E& s,F& ... t )
-	{
-		_stringListToStrings( s,0,size_t( s.size() ),t ... ) ;
-	}
-
 	struct entry
 	{
 		entry()
@@ -150,13 +127,13 @@ public:
 	private:
 		void config( const QStringList& e )
 		{
-			favorites::stringListToStrings( e,
-							volumePath,
-							mountPointPath,
-							autoMountVolume,
-							configFilePath,
-							idleTimeOut,
-							mountOptions ) ;
+			utility2::stringListToStrings( e,
+						      volumePath,
+						      mountPointPath,
+						      autoMountVolume,
+						      configFilePath,
+						      idleTimeOut,
+						      mountOptions ) ;
 
 			if( configFilePath == "N/A" ){
 
