@@ -29,7 +29,7 @@
 
 #include "options.h"
 #include "dialogmsg.h"
-#include "task.h"
+#include "task.hpp"
 #include "utility.h"
 #include "lxqt_wallet.h"
 #include "utility2.h"
@@ -142,6 +142,8 @@ void keyDialog::setUpInitUI()
 
 	m_reUseMountPoint = utility::reUseMountPoint() ;
 
+	m_checkBoxOriginalText = m_ui->checkBoxOpenReadOnly->text() ;
+
 	connect( m_ui->pbCancel,SIGNAL( clicked() ),
 		 this,SLOT( pbCancel() ) ) ;
 	connect( m_ui->pbOpen,SIGNAL( clicked() ),
@@ -440,9 +442,9 @@ void keyDialog::pbOptions()
 
 			this->hide() ;
 
-			configFileOption::instance( this,m_exe,[ this ]( const QStringList& e ){
+			ecryptfscreateoptions::instance( this,[ this ]( const QStringList& e ){
 
-				utility2::stringListToStrings( e,m_configFile ) ;
+				utility2::stringListToStrings( e,m_createOptions,m_configFile ) ;
 
 				this->ShowUI() ;
 			} ) ;
@@ -540,6 +542,11 @@ bool keyDialog::eventFilter( QObject * watched,QEvent * event )
 
 void keyDialog::cbMountReadOnlyStateChanged( int state )
 {
+	if( this->upgradingFileSystem() ){
+
+		return ;
+	}
+
 	auto e = utility::setOpenVolumeReadOnly( this,state == Qt::Checked ) ;
 
 	m_ui->checkBoxOpenReadOnly->setEnabled( false ) ;
@@ -818,20 +825,32 @@ void keyDialog::pbOpen()
 	}
 }
 
-bool keyDialog::completed( const siritask::cmdStatus& s,const QString& m )
+void keyDialog::openMountPoint( const QString& m )
+{
+	if( utility::autoOpenFolderOnMount() ){
+
+		utility::Task::exec( m_fileManagerOpen + " " + utility::Task::makePath( m ) ) ;
+	}
+}
+
+void keyDialog::reportErrorMessage( const siritask::cmdStatus& s )
 {
 	QString msg ;
 
+	if( s == siritask::status::cryfsMigrateFileSystem ){
+
+		m_ui->checkBoxOpenReadOnly->setText( tr( "Upgrade File System" ) ) ;
+	}else{
+		m_ui->checkBoxOpenReadOnly->setText( m_checkBoxOriginalText ) ;
+	}
+
 	switch( s.status() ){
 
 	case siritask::status::success :
 
-		if( utility::autoOpenFolderOnMount() ){
-
-			utility::Task::exec( m_fileManagerOpen + " " + utility::Task::makePath( m ) ) ;
-		}
-
-		return true ;
+		/*
+		 * Should not get here
+		 */
 
 	case siritask::status::cryfs :
 
@@ -875,7 +894,8 @@ bool keyDialog::completed( const siritask::cmdStatus& s,const QString& m )
 
 	case siritask::status::cryfsMigrateFileSystem :
 
-		msg = tr( "SiriKali Can Not Unlock This Volume Because Its FileSystem Has To Manually Be Converted To The Version Of Cryfs That Is Currently In Use.\n\nRun Cryfs With This Volume To Manually Update This Volume's FileSystem." ) ;
+		msg = tr( "This Volume Of Cryfs Needs To Be Upgraded To Work With The Version Of Cryfs You Are Using.\n\nThe Upgrade is IRREVERSIBLE And The Volume Will No Longer Work With Older Versions of Cryfs.\n\nTo Do The Upgrade, Check The \"Upgrade File System\" Option And Unlock The Volume Again." ) ;
+
 		break;
 
 	case siritask::status::encfsNotFound :
@@ -919,8 +939,6 @@ bool keyDialog::completed( const siritask::cmdStatus& s,const QString& m )
 	}
 
 	this->showErrorMessage( { s,msg } ) ;
-
-	return false ;
 }
 
 void keyDialog::showErrorMessage( const QString& e )
@@ -998,6 +1016,14 @@ void keyDialog::encryptedFolderCreate()
 		return ;
 	}
 
+	if( m_exe == "Ecryptfs" ){
+
+		if( m_createOptions.isEmpty() ){
+
+			m_createOptions = "-o " + ecryptfscreateoptions::defaultCreateOptions() ;
+		}
+	}
+
 	m_working = true ;
 
 	siritask::options s{ path,m,m_key,m_idleTimeOut,m_configFile,
@@ -1007,10 +1033,13 @@ void keyDialog::encryptedFolderCreate()
 
 	m_working = false ;
 
-	if( this->completed( e,m ) ){
+	if( e == siritask::status::success ){
 
+		this->openMountPoint( m ) ;
 		this->HideUI() ;
 	}else{
+		this->reportErrorMessage( e ) ;
+
 		if( m_ui->cbKeyType->currentIndex() == keyDialog::Key ){
 
 			m_ui->lineEditKey->clear() ;
@@ -1157,6 +1186,14 @@ void keyDialog::encryptedFolderMount()
 		return ;
 	}
 
+	if( this->upgradingFileSystem() ){
+
+		if( m_ui->checkBoxOpenReadOnly->isChecked() ){
+
+			m_mountOptions += " --allow-filesystem-upgrade" ;
+		}
+	}
+
 	m_working = true ;
 
 	siritask::options s{ m_path,m,m_key,m_idleTimeOut,m_configFile,m_exe,ro,m_mountOptions,QString() } ;
@@ -1165,11 +1202,15 @@ void keyDialog::encryptedFolderMount()
 
 	m_working = false ;
 
-	if( this->completed( e,m ) ){
+	if( e == siritask::status::success ){
+
+		this->openMountPoint( m ) ;
 
 		this->enableAll() ;
 		this->unlockVolume() ;
 	}else{
+		this->reportErrorMessage( e ) ;
+
 		m_ui->lineEditKey->clear() ;
 
 		this->enableAll() ;
@@ -1178,6 +1219,11 @@ void keyDialog::encryptedFolderMount()
 	}
 }
 
+bool keyDialog::upgradingFileSystem()
+{
+	return m_ui->checkBoxOpenReadOnly->text().remove( "&" ) == tr( "Upgrade File System" ).remove( "&" ) ;
+}
+
 void keyDialog::openVolume()
 {
 	auto keyType = m_ui->cbKeyType->currentIndex() ;
