@@ -40,6 +40,7 @@ class QTableWidget ;
 #include "securefscreateoptions.h"
 #include "cryfscreateoptions.h"
 #include "gocryptfscreateoptions.h"
+#include "ecryptfscreateoptions.h"
 
 #include <functional>
 #include <memory>
@@ -175,6 +176,8 @@ private :
 
 	void showErrorMessage( const siritask::cmdStatus& ) ;
 	void showErrorMessage( const QString& ) ;
+	void reportErrorMessage( const siritask::cmdStatus& ) ;
+	void openMountPoint( const QString& ) ;
 
 	void setUIVisible( bool ) ;
 	void keyAndKeyFile( void ) ;
@@ -184,6 +187,7 @@ private :
 	void windowSetTitle( const QString& = QString() ) ;
 	void closeEvent( QCloseEvent * ) ;
 
+	bool upgradingFileSystem( void ) ;
 	bool mountedAll() ;
 	bool completed( const siritask::cmdStatus&,const QString& m ) ;
 	bool eventFilter( QObject * watched,QEvent * event ) ;
@@ -192,6 +196,7 @@ private :
 
 	QByteArray m_key ;
 
+	QString m_checkBoxOriginalText ;
 	QString m_path ;
 	QString m_deviceOffSet ;
 	QString m_idleTimeOut ;
