@@ -301,6 +301,12 @@ namespace utility
 
 	bool enableRevealingPasswords( void ) ;
 
+	void enableDebug( bool ) ;
+	bool debugEnabled( void ) ;
+
+	void enableFullDebug( bool ) ;
+	bool debugFullEnabled( void ) ;
+
 	enum class background_thread{ True,False } ;
 	bool enablePolkit( utility::background_thread ) ;
 
